"use strict";
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dnum-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dnum-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.BatchProcessParent = exports.BatchProcess = void 0;
/**
 * hornet-js-batch - Ensemble des composants de gestion de base hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.5.0
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */
const hornet_js_utils_1 = require("hornet-js-utils");
const logger_1 = require("hornet-js-logger/src/logger");
const promise_api_1 = require("hornet-js-utils/src/promise-api");
const batch_status_1 = require("hornet-js-batch/src/core/batch-status");
const logger = logger_1.Logger.getLogger("hornet-js-batch.batch-process");
class BatchProcess {
    constructor(config) {
        this._options = {};
        this._status = batch_status_1.STATUS.INIT;
        this._options.config = config;
    }
    set result(result) {
        this._result = result;
    }
    get result() {
        return this._result;
    }
    set total(total) {
        this._total = total;
    }
    get total() {
        return this._total;
    }
    set list(list) {
        this._list = list;
    }
    get list() {
        return this._list;
    }
    set name(name) {
        this._name = name;
    }
    get name() {
        return this._name || this.constructor["name"];
    }
    set idBatch(id) {
        this._idBatch = id;
    }
    get idBatch() {
        return this._idBatch;
    }
    set batch(batch) {
        this._batch = batch;
    }
    get batch() {
        return this._batch;
    }
    set options(options) {
        this._options = options;
    }
    get options() {
        return this._options;
    }
    set status(status) {
        this._status = status;
        this._batch.updateStatus();
        if (status === batch_status_1.STATUS.FAILED || status === batch_status_1.STATUS.SUCCEEDED) {
            if (this.timer) {
                clearInterval(this.timer);
            }
        }
    }
    get status() {
        return this._status;
    }
    print() {
        if (this.list && this._total) {
            const calc = 100 - ((100.0 * this.list.length) / this._total);
            logger.trace(this.name + " " + calc.toFixed(2));
        }
    }
    execute() {
        const timer = hornet_js_utils_1.Utils.config.getOrDefault("batch.printTimer", 500);
        this.status = batch_status_1.STATUS.RUNNING;
        this.timer = setInterval(this.print.bind(this), timer);
        return this.treatment();
    }
}
exports.BatchProcess = BatchProcess;
class BatchProcessParent extends BatchProcess {
    constructor(child) {
        super(null);
        this.child = child;
    }
    set idBatch(id) {
        this.child.forEach((value) => {
            value.idBatch = id;
        });
        this._idBatch = "ProcessParent";
    }
    set batch(batch) {
        this.child.forEach((value) => {
            value.batch = batch;
        });
        this._batch = batch;
    }
    updateStatus() {
        const res = this.child.reduce((result, process) => {
            let res = false;
            const status = process.status;
            if (status === batch_status_1.STATUS.SUCCEEDED) {
                res = true;
            }
            else {
                this.status = status;
            }
            return result && res;
        }, true);
        if (res) {
            this.status = batch_status_1.STATUS.SUCCEEDED;
        }
    }
    treatment() {
        const promises = [];
        //
        this.child.forEach((value) => {
            value.options.arg = this.options.args;
            promises.push(value.execute());
        });
        return promise_api_1.Promise.all(promises).then((result) => {
            let res = [];
            result.forEach((value, index) => {
                res = res.concat(value);
            });
            this.status = batch_status_1.STATUS.SUCCEEDED;
            this.result = res;
            return this.result;
        });
    }
}
exports.BatchProcessParent = BatchProcessParent;

//# sourceMappingURL=batch-process.js.map
