"use strict";
/**
 * Copyright ou © ou Copr. Ministère de l'Europe et des Affaires étrangères (2017)
 * <p/>
 * pole-architecture.dnum-psi@diplomatie.gouv.fr
 * <p/>
 * Ce logiciel est un programme informatique servant à faciliter la création
 * d'applications Web conformément aux référentiels généraux français : RGI, RGS et RGAA
 * <p/>
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 * <p/>
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 * <p/>
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 * <p/>
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 * <p/>
 * <p/>
 * Copyright or © or Copr. Ministry for Europe and Foreign Affairs (2017)
 * <p/>
 * pole-architecture.dnum-psi@diplomatie.gouv.fr
 * <p/>
 * This software is a computer program whose purpose is to facilitate creation of
 * web application in accordance with french general repositories : RGI, RGS and RGAA.
 * <p/>
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 * <p/>
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited
 * liability.
 * <p/>
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 * <p/>
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEFAULT_HORNET_BATCH_MIDDLEWARES = exports.BatchRenderingMiddleware = void 0;
/**
 * hornet-js-batch - Ensemble des composants de gestion de base hornet-js
 *
 * @author MEAE - Ministère de l'Europe et des Affaires étrangères
 * @version v5.5.0
 * @link git+https://github.com/diplomatiegouvfr/hornet-js.git
 * @license CECILL-2.1
 */
const middlewares_1 = require("hornet-js-core/src/middleware/middlewares");
const hornet_js_utils_1 = require("hornet-js-utils");
const logger_1 = require("hornet-js-logger/src/logger");
const technical_error_1 = require("hornet-js-utils/src/exception/technical-error");
const abstract_routes_1 = require("hornet-js-core/src/routes/abstract-routes");
const hornet_result_1 = require("hornet-js-core/src/result/hornet-result");
const abstract_batch_routes_1 = require("../routes/abstract-batch-routes");
const batch_executor_1 = require("hornet-js-batch/src/core/batch-executor");
const result_batch_1 = require("hornet-js-batch/src/result/result-batch");
const result_json_1 = require("hornet-js-core/src/result/result-json");
const async_executor_1 = require("hornet-js-core/src/executor/async-executor");
const async_element_1 = require("hornet-js-core/src/executor/async-element");
const validation_error_1 = require("hornet-js-utils/src/exception/validation-error");
const promise_api_1 = require("hornet-js-utils/src/promise-api");
const clonedeep = require("lodash.clonedeep");
// ------------------------------------------------------------------------------------------------------------------- //
//                                      BatchMiddleware
// ------------------------------------------------------------------------------------------------------------------- //
class BatchRenderingMiddleware extends middlewares_1.AbstractHornetMiddleware {
    constructor() {
        super((req, res, next) => {
            BatchRenderingMiddleware.logger.trace(req.originalUrl);
            try {
                const routeInfos = hornet_js_utils_1.Utils.getCls("hornet.routeInfos");
                // route de type 'DATA' uniquement
                if (hornet_js_utils_1.Utils.getCls("hornet.routeType") === abstract_routes_1.RouteType.DATA) {
                    const dataRouteInfos = routeInfos;
                    if (!dataRouteInfos) {
                        const mess = "DataRouteInfos inexistant pour l'url : " + req.originalUrl;
                        BatchRenderingMiddleware.logger.warn(mess);
                        throw new technical_error_1.TechnicalError("ERR_TECH_UNKNOWN", { errorMessage: mess, httpStatus: 200 });
                    }
                    else {
                        const executor = new async_executor_1.AsyncExecutor();
                        executor.addElement(new async_element_1.AsyncElement((next) => {
                            const action = new (dataRouteInfos.getAction())();
                            action.req = req;
                            action.res = res;
                            action.attributes = routeInfos.getAttributes();
                            const actionService = dataRouteInfos.getService();
                            if (actionService) {
                                if (!actionService.prototype) {
                                    action.service = actionService;
                                }
                                else {
                                    BatchRenderingMiddleware.logger.deprecated("Les services doivent être instanciés afin de pouvoir être utilisés par le composant BatchRenderingMiddleware. Les services non instanciés ne seront bientôt plus supportés. Voir l'utilisation de l'injector avec un scope SINGLETON par exemple ou l'instanciation dans la déclaration de vos routes");
                                    action.service = new actionService();
                                }
                            }
                            const validator = action.getDataValidator();
                            if (validator) {
                                const data = clonedeep(action.getPayload());
                                const validationRes = validator.validate(data);
                                if (!validationRes.valid) {
                                    BatchRenderingMiddleware.logger.warn("Données invalides (la validation aurait dû être effectuée côté client) : ", validationRes.errors);
                                    throw new validation_error_1.ValidationError();
                                }
                            }
                            BatchRenderingMiddleware.logger.debug(req.originalUrl + " req");
                            let exec;
                            const query = batch_executor_1.BatchExecutor.Instance.isBatchActionExist(req.originalUrl.replace(/\?batchHistory$/ig, '').replace(/&batchHistory$/ig, ''));
                            const isHistory = req.query.batchHistory !== undefined && req.query.batchHistory === "";
                            const isBusy = query["isBusy"];
                            if (action instanceof abstract_batch_routes_1.RouteActionBatch && isBusy) {
                                exec = promise_api_1.Promise.resolve(new result_batch_1.ResultBatch({ isExist: isBusy }));
                            }
                            else if (!isHistory) {
                                exec = action.execute();
                            }
                            else {
                                exec = promise_api_1.Promise.resolve(new result_batch_1.ResultBatch({ data: {} }));
                            }
                            exec.then((result) => {
                                // pas d'erreur si on est ici > on construit un ApiResult
                                BatchRenderingMiddleware.logger.debug(req.originalUrl + " res");
                                if (result instanceof hornet_result_1.HornetResult) {
                                    let _data = result.options["data"];
                                    if (!_data) {
                                        _data = {};
                                    }
                                    _data["history"] = query["history"];
                                }
                                else {
                                    result["history"] = query["history"];
                                }
                                const newResult = (result instanceof hornet_result_1.HornetResult) ?
                                    result : new result_json_1.ResultJSON({ data: result });
                                return newResult.manageResponse(res);
                            }).then((send) => {
                                if (send) {
                                    res.end();
                                }
                            }).catch((error) => {
                                BatchRenderingMiddleware.logger.error("Erreur de service..." + error);
                                next(error);
                            });
                        }));
                        executor.on("end", (err) => {
                            if (err) {
                                next(err);
                            }
                        });
                        executor.execute();
                    }
                }
            }
            catch (e) {
                next(e);
            }
        });
    }
}
exports.BatchRenderingMiddleware = BatchRenderingMiddleware;
BatchRenderingMiddleware.logger = logger_1.Logger.getLogger("hornet-js-core.middlewares.DataRenderingMiddleware");
exports.DEFAULT_HORNET_BATCH_MIDDLEWARES = [
    middlewares_1.HornetContextInitializerMiddleware,
    middlewares_1.LoggerTIDMiddleware,
    middlewares_1.BodyParserJsonMiddleware,
    middlewares_1.BodyParserUrlEncodedMiddleware,
    middlewares_1.LoggerUserMiddleware,
    middlewares_1.RouterServerMiddleware,
    middlewares_1.UserAccessSecurityMiddleware,
    BatchRenderingMiddleware,
];

//# sourceMappingURL=middlewares.js.map
